# juspay-expresscheckout-python3-client

This is version is ported from existing expresscheckout-python-client.

## Reference

[expresscheckout-python-client](https://bitbucket.org/juspay/expresscheckout-python-client/)
[juspay docs](https://juspay.in/docs/advanced/ec/)

## tools used

2to3

## requirements

certifi==2017.11.5

chardet==3.0.4

idna==2.6

juspay==1.1.2

requests==2.18.4

urllib3==1.22
